//
//  CommandRecognizer.swift
//  iLoadProject
//
//  Created by Lucas Araujo on 10/11/16.
//  Copyright © 2016 iLoadProject. All rights reserved.
//

import Foundation
import Speech
import AVKit

// Types
typealias CommandAction = (String) -> Void
typealias Command = (String,CommandAction)


class CommandRecognizer: NSObject, SFSpeechRecognizerDelegate{
    
    var commands = [Command]()
    
    private let speechRecognizer = SFSpeechRecognizer(locale: Locale.init(identifier: "en-US"))!
    private var recognitionRequest: SFSpeechAudioBufferRecognitionRequest?
    private var recognitionTask: SFSpeechRecognitionTask?
    private let audioEngine = AVAudioEngine()
    private var audioSession:AVAudioSession!

    
    override init() {
        
        SFSpeechRecognizer.requestAuthorization { (status) in
            if status == .authorized{
                print("speech authorized")
            }else{
                print("speech NOT authorized")
            }
        }
        
    }
    
    func startRecognition(){
        speechRecognizer.delegate = self
        
        if recognitionTask != nil {
            recognitionTask?.cancel()
            recognitionTask = nil
        }
        
        audioSession = createAudioSession()
        
        recognitionRequest = SFSpeechAudioBufferRecognitionRequest()
        
        guard let inputNode = audioEngine.inputNode else {
            fatalError("Audio engine has no input node")
        }
        
        guard let recognitionRequest = recognitionRequest else {
            fatalError("Unable to create an SFSpeechAudioBufferRecognitionRequest object")
        }
        
        recognitionRequest.shouldReportPartialResults = true
        
        recognitionTask = speechRecognizer.recognitionTask(with: recognitionRequest, resultHandler: { (result, error) in
            
            for (word,action) in self.commands{
                if let task = result?.bestTranscription.formattedString{
                    
                    let words = task.components(separatedBy: " ")
                    if words.last!.lowercased() == word{
                        action(word)
                    }
                }
            }
            
            print(result?.bestTranscription.formattedString ?? "")
        })
        
        let recordingFormat = inputNode.outputFormat(forBus: 0)
        inputNode.installTap(onBus: 0, bufferSize: 1024, format: recordingFormat) { (buffer, when) in
            self.recognitionRequest?.append(buffer)
        }
        
        audioEngine.prepare()
        
        do {
            try audioEngine.start()
        } catch {
            print("Error Starting audio Engine.")
        }
        
        print("Ready to listen!")
    }
    
    func endRecognition(){
        
        audioEngine.inputNode?.removeTap(onBus: 0)
        
        self.audioEngine.stop()
        
        do{
            try audioSession.setActive(false)
        } catch {
        
        }
    }
    
    func addCommand(word:String, action: @escaping CommandAction){
        commands.append((word,action))
    }
    
    
    func createAudioSession() -> AVAudioSession{
        let audioSession = AVAudioSession.sharedInstance()
        do {
            try audioSession.setCategory(AVAudioSessionCategoryRecord)
            try audioSession.setMode(AVAudioSessionModeMeasurement)
            try audioSession.setActive(true, with: .notifyOthersOnDeactivation)
        } catch {
            print("audioSession properties weren't set because of an error.")
        }
        return audioSession
    }
}


