//
//  LPExerciseResultsViewController.swift
//  iLoadProject
//
//  Created by Lucas Freitas de Oliveira on 28/10/16.
//  Copyright © 2016 iLoadProject. All rights reserved.
//

import UIKit

class LPExerciseResultsViewController: UIViewController, UITableViewDelegate {

    @IBOutlet weak var totalDurationLabel: UILabel!
    @IBOutlet weak var totalWorkLabel: UILabel!
    @IBOutlet weak var currentDurationLabel: UILabel!
    @IBOutlet weak var repetitionsResumeTableView: UITableView!
    @IBOutlet weak var startButton: UIButton!
    @IBOutlet weak var repetitionsButton: UIButton!
    
    //CommandRecognizer
//    var commandRec:CommandRecognizer!
    
    var load:Double!
    var distance:Double!
    var numberOfSeries:Int!
    var exercise: LPExercise!
    var user: User!
    var timer: Timer?
    var repetitionsArray = [LPRepetition]()
    var series = [LPSerie]()
    var startTime = TimeInterval()
    var dateStarted: Date!
    
    var isRunning:Bool = false{
        didSet{
            var text:String!
            if(isRunning){
                text = "Repetir"
                startButton.backgroundColor = UIColor(red: 92/255, green: 202/255, blue: 250/255, alpha: 1.0)
//                UIView.animate(withDuration: 0.3, animations: {
//                    let imageView = self.startButton.viewWithTag(10) as! UIImageView
//                    imageView.image = #imageLiteral(resourceName: "bot_repetir")
//                })
                
            }else{
                text = "Começar"
                startButton.backgroundColor = UIColor(red: 153/255, green: 228/255, blue: 70/255, alpha: 1.0)
//                UIView.animate(withDuration: 0.3, animations: {
//                    let imageView = self.startButton.viewWithTag(10) as! UIImageView
//                    imageView.image = #imageLiteral(resourceName: "bot_comecar")
//                })
                
            }
            startButton.setTitle(text, for: .normal)
        }
    }
    
    var minutes: UInt8?
    var seconds: UInt8?
    var fraction: UInt8?
    
    var elapsed = Date()
    var elapsedTime:Double!
    var totalSeconds: Double!
    var repetitionSeconds: Double!
    var lastRepetition: Double! = 0
    
    override func viewDidLoad() {
        super.viewDidLoad()
        
        startButton.layer.cornerRadius = 10
        startButton.clipsToBounds = true
        startButton.layer.borderColor = UIColor.black.cgColor
        startButton.layer.borderWidth = 0.5
        
        repetitionsButton.layer.cornerRadius = 10
        repetitionsButton.clipsToBounds = true

        
//        let backgroundButton = UIImageView(image: #imageLiteral(resourceName: "bot_comecar"))
//        backgroundButton.contentMode = .scaleAspectFill
//        backgroundButton.frame = self.startButton.bounds
//        backgroundButton.tag = 10
//        self.startButton.addSubview(backgroundButton)
        
        repetitionsResumeTableView.delegate = self
        repetitionsResumeTableView.dataSource = self
        repetitionsResumeTableView.backgroundColor = UIColor.clear
        
//        commandRec = CommandRecognizer()
//        commandRec.addCommand(word: "go", action: {(word) in
//            self.startTimer(self)
//        })
        
//        commandRec.addCommand(word: "stop", action: {(word) in
//            self.startTimer(self)
//        })
//        
//        commandRec.startRecognition()
        
        isRunning = false
        
        //Setting background
        let backgroundImage = UIImageView(image: #imageLiteral(resourceName: "fundo_app"))
        backgroundImage.contentMode = .scaleAspectFill
        backgroundImage.frame = self.view.frame
        backgroundImage.layer.zPosition = 0
        self.view.addSubview(backgroundImage)
        self.view.sendSubview(toBack: backgroundImage)
        
    }

    @IBAction func startTimer(_ sender: AnyObject) {
        
        if isRunning == false{
            self.startTimer()
            dateStarted = Date()
        }
        else{
            
            lastRepetition = totalSeconds
            
            let alert = LPRepetitionsCountViewController.createRepetitionsDefault(delegate: self)
            
            alert.duration = lastRepetition
            alert.load = self.load
            alert.distance = self.distance
            
            self.present(alert, animated: true, completion: nil)
            self.endTimer()
        }
    }
    
    @IBAction func countRepetitions(_ sender: AnyObject) {
        
//        commandRec.endRecognition()
        
        
        
        dismiss(animated: true, completion: nil)
    }

    func updateTime() {
        let currentTime = NSDate.timeIntervalSinceReferenceDate
        
        var elapsedTime:TimeInterval = currentTime - startTime
        totalDurationLabel.text = Double(elapsedTime).formatInTime()
        
        minutes = UInt8(elapsedTime / 60.0)
        elapsedTime -= (TimeInterval(minutes!) * 60)
        
        seconds = UInt8(elapsedTime)
        elapsedTime -= TimeInterval(seconds!)
        
        fraction = UInt8(elapsedTime * 100)
        
        
        totalSeconds = Double(seconds!) + Double(fraction!)/100
        repetitionSeconds = totalSeconds - lastRepetition
        
        currentDurationLabel.text = repetitionSeconds.formatInTime()
    }
    
    func startTimer(){
        self.elapsed = Date()
        self.elapsedTime = 0
        self.totalSeconds = 0
        self.repetitionSeconds = 0
        self.lastRepetition = 0
        
        if timer == nil {
            
            isRunning = true
            let aSelector : Selector = #selector(LPExerciseResultsViewController.updateTime)
            
            DispatchQueue.main.async {
                self.timer = Timer.scheduledTimer(timeInterval: 0.01, target: self, selector: aSelector, userInfo: nil, repeats: true)
                self.startTime = NSDate.timeIntervalSinceReferenceDate
            }
        }
    }
    
    func endTimer(){
        isRunning = false
        timer!.invalidate()
        timer = nil
        repetitionSeconds = 0.0
        totalDurationLabel.text = 0.0.formatInTime()
        currentDurationLabel.text = repetitionSeconds.formatInTime()
    }
    
    
}



extension LPExerciseResultsViewController: UITableViewDataSource {

    func tableView(_ tableView: UITableView, numberOfRowsInSection section: Int) -> Int {
        return repetitionsArray.count
    }
    
    func tableView(_ tableView: UITableView, cellForRowAt indexPath: IndexPath) -> UITableViewCell {
        
        let cell = repetitionsResumeTableView.dequeueReusableCell(withIdentifier: "repetitionsCell", for: indexPath) as! LPRepetitionResumeTableViewCell
        
        let index = indexPath.row
        let repetition = repetitionsArray[index]
        
        cell.backgroundColor = UIColor.clear
        cell.exerciseWorkLabel.text = "\(repetition.work.format(2)) J"
        cell.repetitionDurationLabel.text = "\(repetition.duration) s "
        cell.numberOfRepetitionsLabel.text = "\(repetition.count) vezes"
        
        return cell
    }

    
}

extension LPExerciseResultsViewController: PresenteRepetitionsViewControllerDelegate {
    
    
    func presentResult(workoutFinal: LPWorkoutFinalResult, load: Double, repetitions: Int) {
        
        let rep = LPRepetition(work: workoutFinal.work, duration: workoutFinal.duration, count: repetitions)
        
        workoutFinal.user = user
        
        LPWorkoutFinalResultDAO.save(finalResult: workoutFinal)
        
        let serie = LPSerie(load: load, repetitions: repetitions, exercise: self.exercise, finalResutl: workoutFinal, startDate: dateStarted)

        LPSerieDAO.save(serie: serie)
        
        repetitionsArray.insert(rep, at: 0)
        
        let indexPath = IndexPath(row: 0, section: 0)
        
        repetitionsResumeTableView.insertRows(at: [indexPath], with: .fade)
        repetitionsResumeTableView.scrollToRow(at: indexPath, at: .top, animated: true)
        
        var totalWork = 0.0
        for rep in repetitionsArray{
            let work = rep.work
            totalWork += work
        }
        
        totalWorkLabel.text = "\(totalWork.format(2)) J"
        
        
    }
    
}
