//
//  ViewController.swift
//  iLoadProject
//
//  Created by Lucas Araujo on 28/10/16.
//  Copyright © 2016 iLoadProject. All rights reserved.
//

import UIKit

enum ExerciseAlertTextFieldType:Int{
    case load = 20
    case series
    case distance
    case repetitions
}

class LPExercisesViewController: UIViewController, UITableViewDelegate {

    var exercises = [LPExercise]()
    
    @IBOutlet weak var exercisesTableView: UITableView!
    
    override func viewDidLoad() {
        super.viewDidLoad()
        
        verifyCurrentUser()
        
        exercisesTableView.dataSource = self
        exercisesTableView.delegate = self
        
        navigationItem.title = "iLoad"
//        let exercise = LPExercise(name: "Supino Reto", detail: "muito bom", level: .easy, muscle: .chest)
        //exercises.append(exercise)
        //exercises.append(exercise)
        //exercises.append(exercise)
        
        let backgroundImage = UIImageView(frame: self.view.frame)
        backgroundImage.contentMode = .scaleAspectFill
        backgroundImage.layer.zPosition = 0
        backgroundImage.createGradientLayer()
        exercisesTableView.backgroundView = backgroundImage
        
    }
    
    override func viewWillAppear(_ animated: Bool) {
        super.viewWillAppear(animated)
        loadExercises()
        
        guard let user = UserDAO.getCurrentUser() else { return }
        self.navigationItem.title = user.name
        self.tabBarItem.title = "Exercícios"
        
    }
    
    func loadExercises(){
        exercises = LPExerciseDAO.getAll()
        self.exercisesTableView.reloadData()
    }
    
    func verifyCurrentUser(){
        
        if UserDAO.getCurrentUser() == nil {
            
            let alert = UIAlertController(title: "Bem Vindo", message: "Para Usar o iLoad você precisa selecionar um usuário, clique em OK para selecionar/criar um usuário.", preferredStyle: .alert)
            
            let actOK = UIAlertAction(title: "OK", style: .default, handler: { (action) in
                
                self.performSegue(withIdentifier: "segueUsers", sender: nil)
            })
            alert.addAction(actOK)
            
            self.present(alert, animated: true, completion: { 
                
            })
        }
    }
    
    @IBAction func actAddExercise(_ sender: Any) {
        
        let alertAddExerciseController = UIAlertController(title: "Add Exercício", message: "Coloque um nome e descrição do exercício", preferredStyle: .alert)
        
        let saveAction = UIAlertAction(title: "Save", style: UIAlertActionStyle.default, handler: {
            alert -> Void in
            
            let firstTextField = alertAddExerciseController.textFields![0] as UITextField
            let secondTextField = alertAddExerciseController.textFields![1] as UITextField
            
           let exerciseToSave = LPExercise(name: firstTextField.text!, detail: secondTextField.text!)
            if exerciseToSave.name.characters.count > 0{
                LPExerciseDAO.save(exercise: exerciseToSave)
            }
            self.loadExercises()
            
        })
        saveAction.isEnabled = false
        
        let cancelAction = UIAlertAction(title: "Cancel", style: UIAlertActionStyle.cancel, handler: {
            (action : UIAlertAction!) -> Void in
            
        })
        
        alertAddExerciseController.addTextField { (textField : UITextField!) -> Void in
            textField.placeholder = "Nome"
            NotificationCenter.default.addObserver(forName: NSNotification.Name.UITextFieldTextDidChange, object: textField, queue: OperationQueue.main) { (notification) in
                saveAction.isEnabled = textField.text!.characters.count > 0
            }
        }
        alertAddExerciseController.addTextField { (textField : UITextField!) -> Void in
            textField.placeholder = "Descrição"
        }
        
        alertAddExerciseController.addAction(saveAction)
        alertAddExerciseController.addAction(cancelAction)
        
        self.present(alertAddExerciseController, animated: true) { 
            
        }
        
    }
    
}

extension LPExercisesViewController: UITableViewDataSource{

    
    func tableView(_ tableView: UITableView, numberOfRowsInSection section: Int) -> Int {
        return exercises.count
    }
    
    func tableView(_ tableView: UITableView, cellForRowAt indexPath: IndexPath) -> UITableViewCell {
        
        let cell = exercisesTableView.dequeueReusableCell(withIdentifier: "exerciseCell", for: indexPath) as! LPTableViewExerciseCell
        
        let exercise = exercises[indexPath.row]
        
        cell.backgroundColor = UIColor.clear
        cell.lblExerciseName.textColor = UIColor.white
        cell.lblExerciseName.text = exercise.name
        cell.lblExerciseDetail.text = exercise.detail
        cell.lblExerciseDetail.textColor = .white
        cell.accessoryType = .disclosureIndicator
        
        return cell
    }
    
    @objc(tableView:didSelectRowAtIndexPath:) func tableView(_ tableView: UITableView, didSelectRowAt indexPath: IndexPath) {
        
        guard let currentUser = UserDAO.getCurrentUser() else {
            
            
            //Colocar o alerta para selecionar usuário aqui
            return
        }
        
        let alertAddExerciseController = UIAlertController(title: "\(currentUser.name!) vai começar um exercício", message: "Coloque as informações do exercício", preferredStyle: .alert)
        
        let saveAction = UIAlertAction(title: "Começar", style: UIAlertActionStyle.default, handler: {
            alert -> Void in
            
            let secondTextField = alertAddExerciseController.textFields![0] as UITextField
            let thirdTextField = alertAddExerciseController.textFields![1] as UITextField

            let load = Double(secondTextField.text!) ?? 1
            var distance = Double(thirdTextField.text!) ?? 1
            
            distance = distance/100
            
            let vc = UIStoryboard(name: "Main", bundle: Bundle.main).instantiateViewController(withIdentifier: "ExerciseTimer") as! LPExerciseResultsViewController
            
            vc.distance = distance
            vc.load = load
            vc.exercise = self.exercises[indexPath.row]
            vc.user = currentUser
            
            self.present(vc, animated: true, completion: nil)
            
            
        })
        
        let cancelAction = UIAlertAction(title: "Cancel", style: .cancel, handler: {
            (action : UIAlertAction!) -> Void in
            
        })
        
        alertAddExerciseController.addTextField { (textField : UITextField!) -> Void in
            textField.placeholder = "Peso (Kg) Ex.: 5"
            textField.keyboardType = .numberPad
        }
        alertAddExerciseController.addTextField { (textField : UITextField!) -> Void in
            textField.placeholder = "Distancia (cm) Ex.: 30"
            textField.keyboardType = .numberPad
        }
        
        let changeUserAction = UIAlertAction(title: "Trocar Usuário", style: .default) { (action) in
            self.performSegue(withIdentifier: "segueUsers", sender: nil)

        }
        alertAddExerciseController.addAction(saveAction)
        alertAddExerciseController.addAction(changeUserAction)
        alertAddExerciseController.addAction(cancelAction)
        
        self.present(alertAddExerciseController, animated: true) {
            
        }
        
        
        tableView.deselectRow(at: indexPath, animated: true)
       
    }
    
    @objc(tableView:heightForRowAtIndexPath:) func tableView(_ tableView: UITableView, heightForRowAt indexPath: IndexPath) -> CGFloat {
        return 80
    }
    
    func tableView(_ tableView: UITableView, canEditRowAt indexPath: IndexPath) -> Bool {
        return true
    }
    
    func tableView(_ tableView: UITableView, titleForDeleteConfirmationButtonForRowAt indexPath: IndexPath) -> String? {
        return "Excluir"
    }
    func tableView(_ tableView: UITableView, commit editingStyle: UITableViewCellEditingStyle, forRowAt indexPath: IndexPath) {
        if editingStyle == .delete{
            tableView.beginUpdates()
            exercises.remove(at: indexPath.row)
            LPExerciseDAO.remove(exercise: exercises)
            tableView.deleteRows(at: [indexPath], with: .fade)
            tableView.endUpdates()
        }
    }
}


extension LPExercisesViewController: PresentExerciseViewControllerDelegate{
    internal func presentNewExercise(load: Double, distance: Double) {
        let vc = UIStoryboard(name: "Main", bundle: Bundle.main).instantiateViewController(withIdentifier: "ExerciseTimer") as! LPExerciseResultsViewController
        
        vc.distance = distance
        vc.load = load
        
        present(vc, animated: true, completion: nil)
        
        print("present exercise view controller \nload: \(load)\ndistance:\(distance)")
    }
}

