//
//  LPSerie.swift
//  iLoadProject
//
//  Created by Lucas Araujo on 28/10/16.
//  Copyright © 2016 iLoadProject. All rights reserved.
//

import UIKit

struct LPRepetition {
    var work:Double
    var duration: Double
    var count: Int
}

class LPSerie: NSObject, NSCoding {
    
    var exercise:LPExercise!
    var load:Double!
    var repetitions:Int!
    var finalResult:LPWorkoutFinalResult!
    var date: Date!
 
    init(load:Double, repetitions:Int, exercise : LPExercise, finalResutl: LPWorkoutFinalResult, startDate: Date) {
        self.load = load
        self.repetitions = repetitions
        self.exercise = exercise
        self.finalResult = finalResutl
        self.date = startDate
    }
    
    required init?(coder aDecoder: NSCoder) {
        exercise = aDecoder.decodeObject(forKey: "exercise") as! LPExercise
        load = aDecoder.decodeObject(forKey: "load")as! Double
        repetitions = aDecoder.decodeObject(forKey: "repetitions")as! Int
        finalResult = aDecoder.decodeObject(forKey: "finalResult") as! LPWorkoutFinalResult
        date = aDecoder.decodeObject(forKey: "date") as! Date
    }
    
    func encode(with aCoder: NSCoder) {
        
        aCoder.encode(exercise, forKey: "exercise")
        aCoder.encode(load, forKey: "load")
        aCoder.encode(repetitions, forKey: "repetitions")
        aCoder.encode(finalResult, forKey: "finalResult")
        aCoder.encode(date, forKey: "date")

    }
}


class LPSerieDAO{
    
    class func save(serie: LPSerie){
        
        var arraySerie = self.getAll()
        
        arraySerie.append(serie)
        
        let arrayData = NSKeyedArchiver.archivedData(withRootObject: arraySerie)
        let userDefaults = UserDefaults.standard
        
        userDefaults.set(arrayData, forKey: "Serie")
        userDefaults.synchronize()
        
    }
    
    class func getAll() -> [LPSerie]{
        
        let userDefaults = UserDefaults.standard
        guard let dataArray = userDefaults.object(forKey: "Serie") as? Data else{ return []}
        guard let getArraySerie = NSKeyedUnarchiver.unarchiveObject(with: dataArray) as? [LPSerie] else { return []}
        
        return getArraySerie
    }
    
    class func remove(serie : [LPSerie]){
        
        let arrayData = NSKeyedArchiver.archivedData(withRootObject: serie)
        let userDefaults = UserDefaults.standard
        
        userDefaults.set(arrayData, forKey: "Serie")
        userDefaults.synchronize()
    }
    
    class func getAll(with user: User) -> [LPSerie]{
        
        let series = self.getAll()
        
        var filteredSeries : [LPSerie] = []
        
        filteredSeries = series.filter { (serie) -> Bool in
            
            if serie.finalResult.user.id == user.id{
                return true
            }else{
                return false
            }
        }
        return filteredSeries
    }
    
    class func getAll(with exercise: LPExercise) -> [LPSerie]{
        
        let series = self.getAll()
        
        var filteredSeries : [LPSerie] = []
        
        filteredSeries = series.filter { (serie) -> Bool in
            
            if serie.exercise.id == exercise.id{
                return true
            }else{
                return false
            }
        }
        return filteredSeries
    }
}
