//
//  LPStartExerciseAlertController.swift
//  iLoadProject
//
//  Created by Lucas Araujo on 28/10/16.
//  Copyright © 2016 iLoadProject. All rights reserved.
//

import UIKit


protocol PresentExerciseViewControllerDelegate{
    func presentNewExercise(load:Double, distance:Double)
}

class LPStartExerciseAlertController: UIAlertController {

    override func viewDidLoad() {
        super.viewDidLoad()
    }
    
    var load:Double?
    var repetitions:Int!
    var distance:Double?
    var delegate:PresentExerciseViewControllerDelegate!
    
    class func createDefault(delegate:PresentExerciseViewControllerDelegate,_ cancelCompletion:@escaping () -> () = {}) -> LPStartExerciseAlertController{
        
        let newAlert = LPStartExerciseAlertController(title: "Novo exercício", message: "", preferredStyle: .alert)
        
        newAlert.addTextField(configurationHandler: newAlert.configureLoadTextField)
        
        newAlert.addTextField(configurationHandler: newAlert.configureDistanceTextField)
        
        let doneAction = UIAlertAction(title: "Ok", style: .default, handler: newAlert.alertAction)
        newAlert.addAction(doneAction)
        
        func cancel(action:UIAlertAction){ cancelCompletion() }
        
        let cancelAction = UIAlertAction(title: "Cancel", style: .cancel, handler: cancel)
        newAlert.addAction(cancelAction)
        
        newAlert.delegate = delegate
        
        return newAlert
    }
    
    func alertAction(action:UIAlertAction){
        if let load = self.load, let distance = self.distance{
            delegate.presentNewExercise(load: load, distance: distance)
        }
    }
    
    func configureLoadTextField(textField:UITextField){
        textField.delegate = self
        textField.tag = ExerciseAlertTextFieldType.load.rawValue
        textField.placeholder = "Peso (Kg) Ex.: 5"
        textField.keyboardType = .numbersAndPunctuation
    }
    
    func configureDistanceTextField(textField:UITextField){
        textField.delegate = self
        textField.tag = ExerciseAlertTextFieldType.distance.rawValue
        textField.placeholder = "Distancia (cm) Ex.: 30"
        textField.keyboardType = .numbersAndPunctuation
    }
}

extension LPStartExerciseAlertController: UITextFieldDelegate {
    
    
    func textFieldDidEndEditing(_ textField: UITextField) {
        
        if textField.text!.isEmpty == false{
        
            switch (textField.tag){
            case ExerciseAlertTextFieldType.load.rawValue:
                load = Double(textField.text!) ?? 1
                break
                
            case ExerciseAlertTextFieldType.distance.rawValue:
                distance = Double(textField.text!) ?? 1
                distance = distance!/100
                break
                
            default:
                break
            }
        }
    }
}
