//
//  LPWorkoutResult.swift
//  iLoadProject
//
//  Created by Lucas Araujo on 28/10/16.
//  Copyright © 2016 iLoadProject. All rights reserved.
//

import UIKit

class LPWorkoutFinalResult: NSObject, NSCoding{
    
    var user: User!
    var velocity:Double!
    var potency:Double!
    var work:Double!
    var duration:Double!
    var distance:Double!
    var repetitions: Double!
    
    override init() {
        
    }
    
    init(duration: Double, distance: Double, load: Double, repetitions: Double) {
        super.init()
        
        self.repetitions = repetitions
        self.velocity = calculateVelocity(distance: distance, repetitions: repetitions, duration: duration)
        self.duration = duration
        self.distance = (distance * 2)
        self.work = calculateWork(distance: distance, repetitions: repetitions, load: load)
        self.potency = calculatePotency(distance: distance, repetitions: repetitions, load: load, duration: duration)
    }
    required init?(coder aDecoder: NSCoder) {
        
        user = aDecoder.decodeObject(forKey: "user") as! User
        velocity = aDecoder.decodeObject(forKey: "velocity") as! Double
        potency = aDecoder.decodeObject(forKey: "potency") as! Double
        work = aDecoder.decodeObject(forKey: "work") as! Double
        duration = aDecoder.decodeObject(forKey: "duration") as! Double
        distance = aDecoder.decodeObject(forKey: "distance") as! Double
    }
    
    func encode(with aCoder: NSCoder) {
        
        aCoder.encode(user, forKey: "user")
        aCoder.encode(velocity, forKey: "velocity")
        aCoder.encode(potency, forKey: "potency")
        aCoder.encode(work, forKey: "work")
        aCoder.encode(duration, forKey: "duration")
        aCoder.encode(distance, forKey: "distance")
    }
    
    private func calculateVelocity(distance: Double, repetitions: Double, duration: Double) -> Double {
        // Velocidade Médica = distância x repetições % tempo
        return ((distance * 1.33) * repetitions) / duration
    }
    
    private func calculateWork(distance: Double, repetitions: Double, load: Double, gravity: Double = 9.80665) -> Double {
        // Trabalho = carga x gravidade x distância x nº de repetições / 1000

        return (load * gravity * (distance * 1.33) * repetitions) / 1000
    }
    
    private func calculatePotency(distance: Double, repetitions: Double, load: Double, duration: Double) -> Double {
        // Potência média =  trabalho / tempo
        
        let work = calculateWork(distance: (distance * 1.33), repetitions: repetitions, load: load)
        return work / duration
    }
    
}

class LPWorkoutFinalResultDAO{
    
    class func save(finalResult: LPWorkoutFinalResult){
        
        var arrayFinalResult = self.getAll()
        
        arrayFinalResult.append(finalResult)
        
        let arrayData = NSKeyedArchiver.archivedData(withRootObject: arrayFinalResult)
        let userDefaults = UserDefaults.standard

        userDefaults.set(arrayData, forKey: "FinalResult")
        userDefaults.synchronize()
        
    }
    
    class func getAll() -> [LPWorkoutFinalResult]{
        
        let userDefaults = UserDefaults.standard
        guard let dataArray = userDefaults.object(forKey: "FinalResult") as? Data else{ return []}
        guard let getArrayFinalResult = NSKeyedUnarchiver.unarchiveObject(with: dataArray) as? [LPWorkoutFinalResult] else { return []}
        
        return getArrayFinalResult
    }
    
    class func remove(finalRestults : [LPWorkoutFinalResult]){
        
        let arrayData = NSKeyedArchiver.archivedData(withRootObject: finalRestults)
        let userDefaults = UserDefaults.standard
        
        userDefaults.set(arrayData, forKey: "FinalResult")
        userDefaults.synchronize()
    }
}

/*

*/
