//
//  ResultViewController.swift
//  iLoadProject
//
//  Created by Andre Santana Ferreira on 09/03/17.
//  Copyright © 2017 iLoadProject. All rights reserved.
//

import UIKit
import MessageUI

class ResultViewController: UIViewController {

    @IBOutlet weak var tableView: UITableView!
    @IBOutlet weak var segmentedControl: UISegmentedControl!
    
    var seeAll : Bool = false
    
    var workouts : [LPSerie] = []
    override func viewDidLoad() {
        super.viewDidLoad()
        setDelegates()
        
//        loadWorkouts()
        let backgroundImage = UIImageView(frame: self.view.frame)
        backgroundImage.contentMode = .scaleAspectFill
        backgroundImage.layer.zPosition = 0
        backgroundImage.createGradientLayer()
        
        tableView.backgroundView = backgroundImage

        
        // Do any additional setup after loading the view.
    }

    override func didReceiveMemoryWarning() {
        super.didReceiveMemoryWarning()
        // Dispose of any resources that can be recreated.
    }
    override func viewWillAppear(_ animated: Bool) {
        loadWorkouts()
        guard let user = UserDAO.getCurrentUser() else {
            self.segmentedControl.setTitle("Eu", forSegmentAt: 0)
            return
        }
        
        self.segmentedControl.setTitle(user.name, forSegmentAt: 0)
    }
    
    func loadWorkouts(){
        if seeAll {
            workouts = LPSerieDAO.getAll()
        }else{
            guard let currentUser = UserDAO.getCurrentUser() else {
                workouts = LPSerieDAO.getAll()
                tableView.reloadData()
                return
            }
            workouts = LPSerieDAO.getAll(with: currentUser)
        }
        tableView.reloadData()
    }

    func setDelegates(){
        tableView.delegate = self
        tableView.dataSource = self
    }
    /*
    // MARK: - Navigation

    // In a storyboard-based application, you will often want to do a little preparation before navigation
    override func prepare(for segue: UIStoryboardSegue, sender: Any?) {
        // Get the new view controller using segue.destinationViewController.
        // Pass the selected object to the new view controller.
    }
    */

    @IBAction func actSeeAllOrMe(_ sender: UISegmentedControl) {
        
        switch sender.selectedSegmentIndex {
        case 0:
            seeAll = false
        default:
            seeAll = true
        }
        loadWorkouts()
    }
    
    @IBAction func actSendCSV(_ sender: Any) {
        
        let documents = NSSearchPathForDirectoriesInDomains(FileManager.SearchPathDirectory.documentDirectory, FileManager.SearchPathDomainMask.userDomainMask, true)
        guard let path = documents.first else { return }
        let filePath = String(NSString(string:path).appendingPathComponent("Results.csv"))
        
        guard let url = URL(string: filePath!) else { return }
        
        let items = ResultExport.toArray(series: workouts)
        
        let operation = CSVOperation(filePath: url, source: items)
        
        operation.completionBlock = {
            
            switch operation.finishedState {
            case .success:
                
                let emailViewController = self.configuredMailComposeViewController(urlPath: url)
                emailViewController.navigationBar.tintColor = UIColor.flatPurpleRed
                if MFMailComposeViewController.canSendMail() {
                    self.present(emailViewController, animated: true, completion: nil)
                }
                
            default:
                break
            }
            
        }
        
        OperationQueue().addOperation(operation)
        
        
        // If the view controller can send the email.
        // This will show an email-style popup that allows you to enter
        // Who to send the email to, the subject, the cc's and the message.
        // As the .CSV is already attached, you can simply add an email
        // and press send.
    }
    
    func configuredMailComposeViewController(urlPath : URL) -> MFMailComposeViewController {
        
        
        
        let emailController = MFMailComposeViewController()
        emailController.mailComposeDelegate = self
        emailController.setSubject("Resultados do iLoad")
        emailController.setMessageBody("Informações exportadas por iLoad™.", isHTML: false)
        
        if let user = UserDAO.getCurrentUser() {
            emailController.setToRecipients([user.email])
        }
        
        do{
            let dataCSV = try NSData(contentsOfFile: urlPath.absoluteString, options: .alwaysMapped)
            
            let csvName = "ResultadosiLoad\(Date().toPresentationFullDateString).csv"
            emailController.addAttachmentData(dataCSV as Data, mimeType: "text/csv", fileName: csvName)

        }catch{
            print(error)
        }
        
        return emailController
    }
}


extension ResultViewController : MFMailComposeViewControllerDelegate{
    
    func mailComposeController(_ controller: MFMailComposeViewController, didFinishWith result: MFMailComposeResult, error: Error?) {
     
        switch result {
        case .sent:
            controller.dismiss(animated: true, completion: nil)
        case .cancelled:
            controller.dismiss(animated: true, completion: nil)
        case .failed:
            controller.dismiss(animated: true, completion: nil)
        case .saved:
            controller.dismiss(animated: true, completion: nil)
        }
    }
    
}

extension ResultViewController: UITableViewDataSource, UITableViewDelegate{
    
    func tableView(_ tableView: UITableView, numberOfRowsInSection section: Int) -> Int {
        return workouts.count
    }
    
    func tableView(_ tableView: UITableView, cellForRowAt indexPath: IndexPath) -> UITableViewCell {
        
        let cell = tableView.dequeueReusableCell(withIdentifier: "cellResult", for: indexPath) as! LPWorkoutResultTableViewCell
        let workout = workouts[indexPath.row]
        cell.lblWork.text = "\(workout.finalResult.work!.format(2))J"
        cell.lblPotency.text = "\(workout.finalResult.potency.format(2))W"
        cell.lblDistance.text = "\(workout.finalResult.distance!.format(2))m"
        cell.lblDuration.text = "\(workout.finalResult.duration!.format(2))s"
        cell.lblVelocity.text = "\(workout.finalResult.velocity!.format(2))m/s"
        cell.lblNameUser.text = "\(workout.finalResult.user.name!)"
        cell.lblExerciseName.text = "\(workout.exercise.name!) \(workout.repetitions!)x \(workout.load!.format(2))kg"

        cell.lblDate.text = "  \(workout.date.toPresentationFullDateString)     "
        cell.lblDate.clipsToBounds = true
        cell.lblDate.layer.cornerRadius = cell.lblDate.frame.height/2
        return cell
        
    }
    
    func numberOfSections(in tableView: UITableView) -> Int {
        return 1
    }
    func tableView(_ tableView: UITableView, commit editingStyle: UITableViewCellEditingStyle, forRowAt indexPath: IndexPath) {
        if editingStyle == .delete{
            tableView.beginUpdates()
            workouts.remove(at: indexPath.row)
            LPSerieDAO.remove(serie: workouts)
            tableView.deleteRows(at: [indexPath], with: .fade)
            tableView.endUpdates()
        }
    }
    func tableView(_ tableView: UITableView, canEditRowAt indexPath: IndexPath) -> Bool {
        return true
    }
    
    func tableView(_ tableView: UITableView, titleForDeleteConfirmationButtonForRowAt indexPath: IndexPath) -> String? {
        return "Excluir"
    }
}
