//
//  User.swift
//  iLoadProject
//
//  Created by Andre Santana Ferreira on 21/03/17.
//  Copyright © 2017 iLoadProject. All rights reserved.
//

import Foundation

class User: NSObject, NSCoding {
    
    var id : String!
    var name: String!
    var cpf: String!
    var email: String!
    var isCurrent: Bool!
    
    init(name: String, CPF: String, email: String) {
        self.id = UUID().uuidString
        self.isCurrent = false
        self.name = name
        self.cpf = CPF
        self.email = email
    }
    
    required init?(coder aDecoder: NSCoder) {
        id = aDecoder.decodeObject(forKey: "id") as! String
        name = aDecoder.decodeObject(forKey: "name")as! String
        cpf = aDecoder.decodeObject(forKey: "cpf")as! String
        email = aDecoder.decodeObject(forKey: "email") as! String
        isCurrent = aDecoder.decodeObject(forKey: "isCurrent")as! Bool
    }
    
    func encode(with aCoder: NSCoder) {
        
        aCoder.encode(id, forKey: "id")
        aCoder.encode(name, forKey: "name")
        aCoder.encode(cpf, forKey: "cpf")
        aCoder.encode(email, forKey: "email")
        aCoder.encode(isCurrent, forKey: "isCurrent")
    }
}


class UserDAO{
    
    fileprivate static var userKey : String = "User"
    fileprivate static var currentUserKey : String = "CurrentUser"

    class func updateArray(users: [User]){
        
        let arrayData = NSKeyedArchiver.archivedData(withRootObject: users)
        let userDefaults = UserDefaults.standard
        
        userDefaults.set(arrayData, forKey: userKey)
        userDefaults.synchronize()
    }
    
    class func save(user: User){
        
        var arrayUsers = self.getAll()
        
        arrayUsers.append(user)
        
        let arrayData = NSKeyedArchiver.archivedData(withRootObject: arrayUsers)
        let userDefaults = UserDefaults.standard
        
        userDefaults.set(arrayData, forKey: userKey)
        userDefaults.synchronize()
        
    }
    
    class func getAll() -> [User]{
        
        let userDefaults = UserDefaults.standard
        guard let dataArray = userDefaults.object(forKey: userKey) as? Data else{ return []}
        guard let getArrayUsers = NSKeyedUnarchiver.unarchiveObject(with: dataArray) as? [User] else { return []}
        
        return getArrayUsers
    }
    
    class func remove(user : [User]){
        
        let arrayData = NSKeyedArchiver.archivedData(withRootObject: user)
        let userDefaults = UserDefaults.standard
        
        userDefaults.set(arrayData, forKey: userKey)
        userDefaults.synchronize()
    }
    
    class func setCurrentUser(user: User){
        
        let data = NSKeyedArchiver.archivedData(withRootObject: user)
        let userDefaults = UserDefaults.standard
        
        userDefaults.set(data, forKey: currentUserKey)
        userDefaults.synchronize()
        
    }
    class func getCurrentUser() -> User? {
        
        let userDefaults = UserDefaults.standard
        guard let data = userDefaults.object(forKey: currentUserKey) as? Data else{ return nil}
        guard let user = NSKeyedUnarchiver.unarchiveObject(with: data) as? User else { return nil}
        
        return user
    }
}
