//
//  UsersViewController.swift
//  iLoadProject
//
//  Created by Andre Santana Ferreira on 21/03/17.
//  Copyright © 2017 iLoadProject. All rights reserved.
//

import UIKit

class UsersViewController: UIViewController {

    @IBOutlet weak var tableView: UITableView!
    
    var users : [User] = []
    var indexPathSelected : IndexPath?
    
    override func viewDidLoad() {
        super.viewDidLoad()

        // Do any additional setup after loading the view.
        setDelegates()
        
        let backgroundImage = UIImageView(frame: self.view.frame)
        backgroundImage.contentMode = .scaleAspectFill
        backgroundImage.layer.zPosition = 0
        backgroundImage.createGradientLayer()
        tableView.backgroundView = backgroundImage
    }

    override func viewWillAppear(_ animated: Bool) {
        super.viewWillAppear(animated)
        
        loadUsers()
    }
    override func didReceiveMemoryWarning() {
        super.didReceiveMemoryWarning()
        // Dispose of any resources that can be recreated.
    }
    
    func setDelegates(){
        self.tableView.delegate = self
        self.tableView.dataSource = self
    }
    
    func loadUsers(){
        
        users = UserDAO.getAll()
        tableView.reloadData()
    }
    /*
    // MARK: - Navigation

    // In a storyboard-based application, you will often want to do a little preparation before navigation
    override func prepare(for segue: UIStoryboardSegue, sender: Any?) {
        // Get the new view controller using segue.destinationViewController.
        // Pass the selected object to the new view controller.
    }
    */
    @IBAction func actBack(_ sender: Any) {
        self.dismiss(animated: true, completion: nil)
    }
    @IBAction func actAddUser(_ sender: Any) {
        
        let alertAddUserController = UIAlertController(title: "Novo Usuário", message: "Para criar um novo usuário você deverá preencher os seguintes campos.", preferredStyle: .alert)
        
        let saveAction = UIAlertAction(title: "Save", style: UIAlertActionStyle.default, handler: {
            alert -> Void in
            
            let nameTextField = alertAddUserController.textFields![0] as UITextField
            let cpfTextField = alertAddUserController.textFields![1] as UITextField
            let emailTextField = alertAddUserController.textFields![2] as UITextField
            
            let userToSave = User(name: nameTextField.text!, CPF: cpfTextField.text!, email: emailTextField.text!)
            if userToSave.name.characters.count > 0{
                if self.users.count == 0{
                    userToSave.isCurrent = true
                }
                UserDAO.setCurrentUser(user: userToSave)
                UserDAO.save(user: userToSave)
                
                self.loadUsers()
            }
        })
        
        let cancelAction = UIAlertAction(title: "Cancel", style: UIAlertActionStyle.default, handler: {
            (action : UIAlertAction!) -> Void in
            
        })
        
        saveAction.isEnabled = false
        alertAddUserController.addTextField { (textField : UITextField!) -> Void in
            textField.placeholder = "Nome"
            NotificationCenter.default.addObserver(forName: NSNotification.Name.UITextFieldTextDidChange, object: textField, queue: OperationQueue.main) { (notification) in
                saveAction.isEnabled = textField.text!.characters.count > 0
            }
        }
        alertAddUserController.addTextField { (textField : UITextField!) -> Void in
            textField.placeholder = "CPF"
            textField.delegate = self
            textField.tag = 1
            textField.keyboardType = .numbersAndPunctuation
        }
        alertAddUserController.addTextField { (textField : UITextField!) -> Void in
            textField.placeholder = "EMAIL"
            textField.keyboardType = .emailAddress
        }
        
        alertAddUserController.addAction(saveAction)
        alertAddUserController.addAction(cancelAction)
        
        self.present(alertAddUserController, animated: true) {
            
        }
    }
}
extension UsersViewController: UITextFieldDelegate{
    
    func textField(_ textField: UITextField, shouldChangeCharactersIn range: NSRange, replacementString string: String) -> Bool {
        if textField.text?.characters.count == 3{
            
            textField.text!.insert(".", at: (textField.text?.index((textField.text?.startIndex)!, offsetBy: 3))!)
        }else if textField.text?.characters.count == 7{
            
            textField.text!.insert(".", at: (textField.text?.index((textField.text?.startIndex)!, offsetBy: 7))!)
        }else if textField.text?.characters.count == 11{
            
            textField.text!.insert("-", at: (textField.text?.index((textField.text?.startIndex)!, offsetBy: 11))!)
        }else if (textField.text?.characters.count)! > 14{
        }
        return true
    }
}
extension UsersViewController: UITableViewDelegate, UITableViewDataSource{
    
    func numberOfSections(in tableView: UITableView) -> Int {
        return 1
    }
    
    func tableView(_ tableView: UITableView, numberOfRowsInSection section: Int) -> Int {
        return users.count
    }
    
    func tableView(_ tableView: UITableView, cellForRowAt indexPath: IndexPath) -> UITableViewCell {
        
        let user = users[indexPath.row]
        let cell = tableView.dequeueReusableCell(withIdentifier: "UserTableViewCell", for: indexPath) as! UserTableViewCell
        
        if user.isCurrent == true{
            indexPathSelected = indexPath
        }
        
        cell.accessoryType = user.isCurrent == true ? .checkmark : .none
        cell.lblCPF.text = user.cpf
        cell.lblName.text = user.name
        cell.lblEmail.text = user.email
        
        return cell
    }
    
    func tableView(_ tableView: UITableView, didSelectRowAt indexPath: IndexPath) {
       // print("DidSelected: ", indexPath.row)
                if let cell = tableView.cellForRow(at: indexPath) {
                    cell.accessoryType = .checkmark
                    
                    let userSelected = users[indexPath.row]
                    if !userSelected.isCurrent{
                       updateCurrentUser(indexPath: indexPath, selected: true)
                        guard let index = indexPathSelected else { return }
                        updateOldUser(indexPath: index, selected: false)
                        guard let oldCell = tableView.cellForRow(at: index) else { return }
                        oldCell.accessoryType = .none
                        indexPathSelected = indexPath

                    }
                }
    }
    
    func tableView(_ tableView: UITableView, titleForDeleteConfirmationButtonForRowAt indexPath: IndexPath) -> String? {
        return "Excluir"
    }
    
    func tableView(_ tableView: UITableView, canEditRowAt indexPath: IndexPath) -> Bool {
        return true
    }
    func tableView(_ tableView: UITableView, commit editingStyle: UITableViewCellEditingStyle, forRowAt indexPath: IndexPath) {
        if editingStyle == .delete{
            tableView.beginUpdates()
            users.remove(at: indexPath.row)
            UserDAO.remove(user: users)
            tableView.deleteRows(at: [indexPath], with: .fade)
            tableView.endUpdates()
        }
    }
    
    func updateCurrentUser(indexPath: IndexPath, selected: Bool){
        
        let userSelected = users[indexPath.row]
        users.remove(at: indexPath.row)
        userSelected.isCurrent = selected
        users.insert(userSelected, at: indexPath.row)
        UserDAO.updateArray(users: users)

        if selected{
            UserDAO.setCurrentUser(user: userSelected)
        }
    }
    
    func updateOldUser(indexPath: IndexPath, selected: Bool){
        
        let userSelected = users[indexPath.row]
        users.remove(at: indexPath.row)
        userSelected.isCurrent = selected
        users.insert(userSelected, at: indexPath.row)
        UserDAO.updateArray(users: users)
    }
}
